==> component-xxljob-spring-boot-starter-2.0.8-20201221.121054-8-sources.jar: com/bxm/newidea/component/schedule/task/ScheduleTask.java <==
package com.bxm.newidea.component.schedule.task;

import com.bxm.newidea.component.schedule.constant.CommonConstant;
import com.bxm.newidea.component.schedule.constant.RouteStrategyEnum;
import com.xxl.job.core.enums.ExecutorBlockStrategyEnum;
import org.apache.commons.lang.StringUtils;

/**
 * 调度任务接口，用于定义调度任务拥有的属性
 * @author zhengxiaofeng
 */
public interface ScheduleTask {

    /**
     * 调度任务名称，用于在调度平台区分任务信息，具有唯一性，重复使用无效
     * @return 任务名称
     */
    String taskName();

    /**
     * 获取调度任务的执行周期
     * 单次执行和周期执行的任务均用cron表达式代替
     * 单次执行任务可使用{@link com.bxm.newidea.component.schedule.utils.CronUtils}进行处理
     * @return 执行周期
     */
    String cron();

    /**
     * 任务描述，说明调度任务的作用
     * @return 任务描述
     */
    default String description() {
        return taskName();
    }

    /**
     * 调度任务的回调接口，在到达任务执行周期时回调
     * @return 回调服务
     */
    TaskCallback callback();

    /**
     * 回调时携带的参数，需要在创建调度任务时传递
     * 支持使用Json结构
     * @return 业务参数
     */
    default String callbackParam() {
        return StringUtils.EMPTY;
    }

    /**
     * 任务路由策略，在执行节点存在多个时，决定如何选择执行点
     * @return 路由策略
     */
    default RouteStrategyEnum routeStrategy() {
        return RouteStrategyEnum.ROUND;
    }

    /**
     * 阻塞策略，在任务执行时前一个任务尚未完成，后续的任务如何调度
     * @return 阻塞策略
     */
    default ExecutorBlockStrategyEnum blockStrategy() {
        return ExecutorBlockStrategyEnum.SERIAL_EXECUTION;
    }

    /**
     * 调度任务的创建者
     * 不怕被喷的人留下名来
     * @return 作者
     */
    default String author() {
        return CommonConstant.DEFAULT;
    }

    /**
     * 是否一次性定时任务
     * @return true表示为一次性任务
     */
    default boolean onceTask() {
        return false;
    }

    /**
     * 定时任务的版本号，如果存在相同服务中的不同版本时，可进行定义，用于防止错误的回调
     * 也可以通过系统属性或者配置中心进行配置
     * 任务属性中定义的版本具有最高优先级
     * @return 当前任务的版本号
     */
    default String version() {
        return StringUtils.EMPTY;
    }
}

==> component-xxljob-spring-boot-starter-2.1.11-sources.jar: com/bxm/newidea/component/schedule/task/ScheduleTask.java <==
package com.bxm.newidea.component.schedule.task;

import com.bxm.newidea.component.schedule.constant.XxljobConstant;
import com.bxm.newidea.component.schedule.constant.XxljobRouteStrategyEnum;
import com.bxm.newidea.component.tools.CronUtil;
import com.xxl.job.core.enums.ExecutorBlockStrategyEnum;
import org.apache.commons.lang.StringUtils;

/**
 * 调度任务接口，用于定义调度任务拥有的属性
 *
 * @author zhengxiaofeng
 */
public interface ScheduleTask {

    /**
     * 调度任务名称，用于在调度平台区分任务信息，具有唯一性，重复使用无效
     *
     * @return 任务名称
     */
    String taskName();

    /**
     * 获取调度任务的执行周期
     * 单次执行和周期执行的任务均用cron表达式代替
     * 单次执行任务可使用{@link CronUtil}进行处理
     *
     * @return 执行周期
     */
    String cron();

    /**
     * 任务描述，说明调度任务的作用
     *
     * @return 任务描述
     */
    default String description() {
        return taskName();
    }

    /**
     * 调度任务的回调接口，在到达任务执行周期时回调
     *
     * @return 回调服务
     */
    TaskCallback callback();

    /**
     * 回调时携带的参数，需要在创建调度任务时传递
     * 支持使用Json结构
     *
     * @return 业务参数
     */
    default String callbackParam() {
        return StringUtils.EMPTY;
    }

    /**
     * 任务路由策略，在执行节点存在多个时，决定如何选择执行点
     *
     * @return 路由策略
     */
    default XxljobRouteStrategyEnum routeStrategy() {
        return XxljobRouteStrategyEnum.ROUND;
    }

    /**
     * 阻塞策略，在任务执行时前一个任务尚未完成，后续的任务如何调度
     *
     * @return 阻塞策略
     */
    default ExecutorBlockStrategyEnum blockStrategy() {
        return ExecutorBlockStrategyEnum.SERIAL_EXECUTION;
    }

    /**
     * 调度任务的创建者
     * 不怕被喷的人留下名来
     *
     * @return 作者
     */
    default String author() {
        return XxljobConstant.DEFAULT;
    }

    /**
     * 是否一次性定时任务
     *
     * @return true表示为一次性任务
     */
    default boolean onceTask() {
        return false;
    }
}
